==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/admin/inc/syntax/clssbindgrid.php <==
<?php
require_once "inc/syntax/clsstdgrid.php";
/***************** Servicebind grid ***********************/
class cServiceBindGrid extends cStdGrid
{
	function cServiceBindGrid($name,$service,$filename)
	{
		$this->Name = $name;
		$this->Service = $service;
		$this->Item = new cSBItem();
		$this->Filename = $_SESSION["CONFIGPATH"]."servicebind.dat";
	}
	
	/* Build grid from buffer */
	function loadFromBuffer()
	{
		  if ($this->Buffer){
			$ic = $oc = 0;
			/* explode buffer to lines */
			$lines = explode(CRLF,$this->Buffer);
			//Parse lines
			for ($i=0;$i<count($lines);$i++){
				$item = array();
				if ($lines[$i]=="") continue; // skip blank lines
				if ($this->Item->Length==1) $item[0]= $lines[$i];
				else{
					$pom = $lines[$i];
          for ($j=0;$j<$this->Item->Length-1;$j++){
						$pom = explode($this->Item->Seps[$j],$pom,2);
						$item[$j] = $pom[0];
						$pom = $pom[1];
					}
					$item[$j] = $pom;
				}
				$item[4] = str_replace($this->Service,"",$item[0])=="SSL"?true:false;
				
				//Store servic
				if (str_replace("SSL","",$item[0])!=$this->Service){
          $this->otherData[$oc++] = $item; 
          continue;
				}
        $items[$ic++] = $item;
			}
			$this->Data = $items;
    }	
	}
	/* Save grid to buffer */
	function saveToBuffer()
	{
		$buffer="";
    //Save actual service data
		if ($this->Data)
		foreach ($this->Data as $i =>$val){
      $this->Data[$i][0] = $this->Service.($this->Data[$i][4]?'SSL':'');
			if ($this->Item->Length==1) $buffer.= $this->Data[$i][0] . CRLF;
			else{
				for ($j=0;$j<$this->Item->Length-1;$j++){
					$buffer.=$this->Data[$i][$j].$this->Item->Seps[$j];
				}
				$buffer.= $this->Data[$i][$j] . CRLF;
			}
		}
		//Set other services data
		if ($this->otherData) foreach ($this->otherData as $i =>$val){
			if ($this->Item->Length==1) $buffer.= $this->otherData[$i][0] . CRLF;
			else{
				for ($j=0;$j<$this->Item->Length-1;$j++){
					$buffer.=$this->otherData[$i][$j].$this->Item->Seps[$j];
				}
				$buffer.= $this->otherData[$i][$j] . CRLF;
			}
		}		
		$this->Buffer = $buffer;
		return $buffer;
	}
	
	/* Load grid from session */
  function loadFromSession(){
		 $this->Data = $_SESSION["griddata"]["grids"][$this->Name];
		 $this->otherData = $_SESSION["griddata"]["other"][$this->Name];
	}
	/* Save grid to session */
	function saveToSession(){
		$_SESSION["griddata"]["grids"][$this->Name] = $this->Data;
		$_SESSION["griddata"]["other"][$this->Name] = $this->otherData;
	}
}

?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/admin/inc/syntax/clssbindgrid.php <==
<?php
require_once "inc/syntax/clsstdgrid.php";
/***************** Servicebind grid ***********************/
class cServiceBindGrid extends cStdGrid
{
	function cServiceBindGrid($name,$service,$filename)
	{
		$this->Name = $name;
		$this->Service = $service;
		$this->Item = new cSBItem();
		$this->Filename = $_SESSION["CONFIGPATH"]."servicebind.dat";
	}
	
	/* Build grid from buffer */
	function loadFromBuffer()
	{
		  if ($this->Buffer){
			$ic = $oc = 0;
			/* explode buffer to lines */
			$lines = explode(CRLF,$this->Buffer);
			//Parse lines
			for ($i=0;$i<count($lines);$i++){
				$item = array();
				if ($lines[$i]=="") continue; // skip blank lines
				if ($this->Item->Length==1) $item[0]= $lines[$i];
				else{
					$pom = $lines[$i];
          for ($j=0;$j<$this->Item->Length-1;$j++){
						$pom = explode($this->Item->Seps[$j],$pom,2);
						$item[$j] = $pom[0];
						$pom = $pom[1];
					}
					$item[$j] = $pom;
				}
				$item[6] = str_replace($this->Service,"",$item[0])=="SSL"?true:false;
				
				//Store servic
				if (str_replace("SSL","",$item[0])!=$this->Service){
          $this->otherData[$oc++] = $item; 
          continue;
				}
        $items[$ic++] = $item;
			}
			$this->Data = $items;
    }
	}
	/* Save grid to buffer */
	function saveToBuffer()
	{
		$buffer="";

    //Save actual service data
		if ($this->Data)
		foreach ($this->Data as $i =>$val){
      $this->Data[$i][0] = $this->Service.($this->Data[$i][4]?'SSL':'');
			if ($this->Item->Length==1) $buffer.= $this->Data[$i][0] . CRLF;
			else{
				for ($j=0;$j<$this->Item->Length-1;$j++){
					$buffer.=$this->Data[$i][$j].$this->Item->Seps[$j];
				}
				$buffer.= $this->Data[$i][$j] . CRLF;
			}
		}
		//Set other services data
		if ($this->otherData) foreach ($this->otherData as $i =>$val){
			if ($this->Item->Length==1) $buffer.= $this->otherData[$i][0] . CRLF;
			else{
				for ($j=0;$j<$this->Item->Length-1;$j++){
					$buffer.=$this->otherData[$i][$j].$this->Item->Seps[$j];
				}
				$buffer.= $this->otherData[$i][$j] . CRLF;
			}
		}		
		$this->Buffer = $buffer;
		return $buffer;
	}
	
	/* Load grid from session */
  function loadFromSession(){
		 $this->Data = $_SESSION["griddata"]["grids"][$this->uid][$this->Name];
		 $this->otherData = $_SESSION["griddata"]["other"][$this->uid][$this->Name];
	}
	/* Save grid to session */
	function saveToSession(){
		$_SESSION["griddata"]["grids"][$this->uid][$this->Name] = $this->Data;
		$_SESSION["griddata"]["other"][$this->uid][$this->Name] = $this->otherData;
	}
}

?>
